==> Apktool-2.12.1.tar.gz: Apktool-2.12.1/brut.apktool/apktool-lib/src/test/java/brut/androlib/AndResGuardTest.java <==
/*
 *  Copyright (C) 2010 Ryszard Wiśniewski <brut.alll@gmail.com>
 *  Copyright (C) 2010 Connor Tumbleson <connor.tumbleson@gmail.com>
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       https://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package brut.androlib;

import brut.common.BrutException;
import brut.directory.ExtFile;

import java.io.File;

import org.junit.*;
import static org.junit.Assert.*;

public class AndResGuardTest extends BaseTest {
    private static final String TEST_APK = "issue1170.apk";

    @BeforeClass
    public static void beforeClass() throws Exception {
        TestUtils.copyResourceDir(AndResGuardTest.class, "issue1170", sTmpDir);
    }

    @Test
    public void checkifAndResDecodeRemapsRFolder() throws BrutException {
        ExtFile testApk = new ExtFile(sTmpDir, TEST_APK);
        ExtFile testDir = new ExtFile(testApk + ".out");
        new ApkDecoder(testApk, sConfig).decode(testDir);

        assertTrue(new File(testDir, "res/mipmap-hdpi-v4/a.png").isFile());
    }

    @Test
    public void checkIfAndResDecodeRemapsRFolderInRawMode() throws BrutException {
        sConfig.setForced(true);
        sConfig.setDecodeResources(Config.DecodeResources.NONE);

        ExtFile testApk = new ExtFile(sTmpDir, TEST_APK);
        ExtFile testDir = new ExtFile(testApk + ".raw.out");
        new ApkDecoder(testApk, sConfig).decode(testDir);

        assertTrue(new File(testDir, "r/a/a.png").isFile());
    }
}

==> Apktool-3.0.1.tar.gz: Apktool-3.0.1/brut.apktool/apktool-lib/src/test/java/brut/androlib/AndResGuardTest.java <==
/*
 *  Copyright (C) 2010 Ryszard Wiśniewski <brut.alll@gmail.com>
 *  Copyright (C) 2010 Connor Tumbleson <connor.tumbleson@gmail.com>
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       https://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package brut.androlib;

import java.io.File;

import org.junit.*;
import static org.junit.Assert.*;

public class AndResGuardTest extends BaseTest {
    private static final String TEST_APK = "issue1170.apk";

    @BeforeClass
    public static void beforeClass() throws Exception {
        copyResourceDir(AndResGuardTest.class, "issue1170", sTmpDir);
    }

    @Test
    public void checkifAndResDecodeRemapsRFolder() throws Exception {
        File testApk = new File(sTmpDir, TEST_APK);
        File testDir = new File(testApk + ".out");
        new ApkDecoder(testApk, sConfig).decode(testDir);

        assertTrue(new File(testDir, "res/mipmap-hdpi-v4/a.png").isFile());
    }

    @Test
    public void checkIfAndResDecodeIgnoresRFolderInRawMode() throws Exception {
        sConfig.setDecodeResources(Config.DecodeResources.NONE);

        File testApk = new File(sTmpDir, TEST_APK);
        File testDir = new File(testApk + ".out.raw");
        new ApkDecoder(testApk, sConfig).decode(testDir);

        assertTrue(new File(testDir, "unknown/r/a/a.png").isFile());
    }
}
